@@ -138,7 +138,7 @@ class VerifyToken:
                         purview_name_id = sear_permission[0]['id']
                     if self.permission_set_db:
                         # 添加权限信息到权限集合（0无权限-1查看-2新增-4编辑-8删除-16下载）
-                        for status in (0, 1, 2, 4, 8, 16, 32):
+                        for status in per['status']:
                             find_dict.update({'permission_status': status})
                             if not self.permission_set_db.does_it_exist(find_dict):
                                 find_dict.update(
